==> dl.php?src=linea21_1_0.zip: linea21/contents/add.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////


$contents_object = new contents;
$complete_type=strtoupper($mod_inc);
$mask_template=array_fill(1, 3, '');
$form_title='';
$form_body='';
$layer_tpl_1 = "style=\"display:block;\"";

if(isset($_POST['enregistrer'])) {
	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$contents_object->AddContents($parent, $data_table, $complete_type, $sql_object);
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
	echo $result;
	if($result===true) header("Location: ".$link_confirm);
	else  system_error();
}

if(isset($_POST['valider'])) {
	$table[0]=$_POST['part_title'];
	$table[1]=$_POST['part_body'];

	if($type=='P') {
		$table[2]=$_POST['part_template'];
		$table[3]=isset($_FILES['visuel1']['name']) ? $_FILES['visuel1']['name'] : '' ;
	}
	$integrity=$contents_object->CheckDataIntegrity($table,$type, 'ROCK');
	
	if(!is_string($integrity)) {
		if (isset($_POST['part_template']) && $_POST['part_template'] != 3) {
			include_once('../class/system/class.upload.php');
			include_once('../class/system/class.image.php');
			$image_object = new image;
            $upload_object = new upload;
            $upload1 = $_FILES['visuel1'];
			$size_integrity=$upload_object->CheckMaxFile($upload1['size'], $contents_object->P_UPLOAD_MAX_MO);
			if(is_string($size_integrity)) $integrity=$size_integrity;
			$format_integrity=$upload_object->CheckExtImage($upload1['name']);
			if(is_string($format_integrity)) $integrity=$format_integrity;

			if(!is_string($integrity)) {
	            $result=$sql_object->DBSelect($req_max_publi_content_id, 'OBJECT');
				$file_name=($result[0]->maxid+1);
				$destination="../".$contents_object->P_URI_INPUT;
				$final_name=$file_name.".".$upload_object->GetExtension($upload1['name']);
				$visual_link1=$destination.$final_name;
				$table[3]=$contents_object->P_URI_INPUT.$final_name;
				$result_upload=$upload_object->UploadFile($upload1, $final_name, $destination);
				
				// cration des thumbs
				$min_name=get_min_name($destination.$final_name);
				$image_object->ThumbCreate($destination.$final_name, $min_name , $contents_object->P_MAX_PHOTO_MIN_WIDTH);
				
				// on retaille l'original au besoin.
				if(PHOTO_RESIZE===true && ExcedMaxSize($destination.$final_name, $contents_object->P_MAX_PHOTO_MAX_WIDTH)) {
					$image_object->ThumbCreate($destination.$final_name, $destination.$final_name , $contents_object->P_MAX_PHOTO_MAX_WIDTH);
				}
				
				// prparation de l'affichage de la miniature
				$visual_link1=EnlargeImage($visual_link1);
			}
        } elseif(isset($_POST['part_template'])) $table[3]='';
	}

	
	if(is_string($integrity)) {
		$text_format='2FIELD';
	} else {
		$text_format='2HTML';
	}
	$form_title=formatText($_POST['part_title'], $text_format);
	$form_body=formatText($_POST['part_body'], $text_format);
	if($type=='P') {
		$mask_template[$_POST['part_template']]=' selected="selected"';
		if($_POST['part_template']==3) $layer_tpl_1 = "style=\"display:none;\"";
	}
	
	$table=urlencode(serialize($table));
}

if($type=='P') {
	$requete= SQL_getPublicationTitle($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['publi_title']);
	$publi_owner=$result[0]['publi_posted_by'];
	//////////// Check Droits utilisateur ////////////
	if (!HaveRight('publication')) ReloadIndex('admin');
	if (GetSessionElement('id')!=$publi_owner && !IsSuperAdmin()) ReloadIndex('admin');
	///////////
	
	// select-box Templates
	$select_template="<select name=\"part_template\" id=\"part_template\" onchange=\"ShowFilesLayer(this.value, 'contents')\">\n";
	$select_template.="<option value=\"1\"".$mask_template[1].">".$contents_object->GetTemplateName(1)."</option>\n";
	$select_template.="<option value=\"2\"".$mask_template[2].">".$contents_object->GetTemplateName(2)."</option>\n";
	$select_template.="<option value=\"3\"".$mask_template[3].">".$contents_object->GetTemplateName(3)."</option>\n";
	$select_template.="</select>\n";
}

if($type=='W') {
	$requete= SQL_getWorkshopRepTitleAndGroup($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['workrep_title']).' ('.FormatText($result[0]['workshop_denomination']).')';
	$workshop_id=$result[0]['workrep_workshop_id'];
	//////////// Check Droits utilisateur ////////////
	if (!HaveRight('workshop')) ReloadIndex('admin');
	if (!AuthUser4Workshop($workshop_id, $sql_object) && !IsSuperAdmin()) ReloadIndex('admin');
	///////////
}




?>

<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu'][$mod_inc]?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['contents'][$mod_inc.'_type']." : ". $current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>

<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
		?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
			<h2><? echo formatTitleh2($GLOBALS['lang']['contents'][$mod_inc.'_type']." : ". $current_title); ?></h2>
			<form id="addpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post" enctype="multipart/form-data">
				<p>
				<label for="part_title"><? echo $GLOBALS['lang']['contents']['title']; ?> : *</label>
				<input name="part_title" type="text" class="textfield" id="part_title" maxlength="200" value="<?php echo $form_title; ?>" />
				</p>
				<p>
				<label for="part_body"><? echo $GLOBALS['lang']['contents']['body']; ?> : *</label>
				<textarea id="part_body" name="part_body" class="largetextfield" <?php echo AREA_SETTINGS; ?>><?php echo $form_body; ?></textarea>
				</p>
				<p>
				<?php  if($type=='P') { ?>
				<label for="part_template" ><? echo $GLOBALS['lang']['contents']['template']; ?> : </label>
				<?php echo $select_template; ?>
				</p>
				<p id="layervisuel1" <?php echo $layer_tpl_1; ?>>
					<label for="visuel1"><?php echo $GLOBALS['lang']['contents']['visu1']; ?></label>
					<input name="visuel1" type="file" size="47" id="visuel1"  class="file" /><br /><br />
				</p>
				<?php } ?>
				<div>
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<?php echo cancel_button($cancel_link); ?>
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Rcapitulatif
} else	{

if($type=='P') {
	if($_POST['part_template']==3) {
		$display_visual=$GLOBALS['lang']['divers']['none'];
	} else {
		$display_visual=$visual_link1;
	}
	$display_template_choice=$contents_object->GetTemplateName($_POST['part_template']);
}

?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
			<h2><? echo $GLOBALS['lang']['recap']['title'] ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['contents']['title']."</dt>\n";
			echo "<dd>".$form_title."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['contents']['body']."</dt>\n";
			echo "<dd>".linkin_content($form_body)."</dd>\n";
			if($type=='P') {
				echo "<dt>".$GLOBALS['lang']['contents']['template']."</dt>\n";
				echo "<dd>".$display_template_choice."</dd>\n";
				echo "<dt>".$GLOBALS['lang']['contents']['visu1']."</dt>\n";
				echo "<dd>".$display_visual."</dd>\n";
			}
			echo "</dl>\n";
			?>
			<form id="addscale" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview'] ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>

==> dl.php?src=linea21_1_1.zip: linea21/contents/add.php <==
<?php
//////////// Check Inclusion de pages ////////////
if (!function_exists('AuthenthificationProcess')) {
    include_once("../lib/lib_common.php");
    ReloadIndex('admin');
} 
////////////


$contents_object = new contents;
$complete_type=strtoupper($mod_inc);
$mask_template=array_fill(1, 3, '');
$form_title='';
$form_body='';
$layer_tpl_1 = "style=\"display:block;\"";

if(isset($_POST['enregistrer'])) {
	$data_table=unserialize(urldecode($_POST['data_table']));
	$result=$contents_object->AddContents($parent, $data_table, $complete_type, $sql_object);
	$link_confirm="confirm.php?rub=".$rub."&todo=".$todo."&type=".$type."&id=".$parent;
	echo $result;
	if($result===true) header("Location: ".$link_confirm);
	else  system_error();
}

if(isset($_POST['valider'])) {
	$table[0]=$_POST['part_title'];
	$table[1]=$_POST['part_body'];

	if($type=='P') {
		$table[2]=$_POST['part_template'];
		$table[3]=isset($_FILES['visuel1']['name']) ? $_FILES['visuel1']['name'] : '' ;
	}
	$integrity=$contents_object->CheckDataIntegrity($table,$type, 'ROCK');
	
	if(!is_string($integrity)) {
		if (isset($_POST['part_template']) && $_POST['part_template'] != 3) {
			include_once('../class/system/class.upload.php');
			include_once('../class/system/class.image.php');
			$image_object = new image;
            $upload_object = new upload;
            $upload1 = $_FILES['visuel1'];
			$size_integrity=$upload_object->CheckMaxFile($upload1['size'], $contents_object->P_UPLOAD_MAX_MO);
			if(is_string($size_integrity)) $integrity=$size_integrity;
			$format_integrity=$upload_object->CheckExtImage($upload1['name']);
			if(is_string($format_integrity)) $integrity=$format_integrity;

			if(!is_string($integrity)) {
	            $result=$sql_object->DBSelect($req_max_publi_content_id, 'OBJECT');
				$file_name=($result[0]->maxid+1);
				$destination="../".$contents_object->P_URI_INPUT;
				$final_name=$file_name.".".$upload_object->GetExtension($upload1['name']);
				$visual_link1=$destination.$final_name;
				$table[3]=$contents_object->P_URI_INPUT.$final_name;
				$result_upload=$upload_object->UploadFile($upload1, $final_name, $destination);
				
				// création des thumbs
				$min_name=get_min_name($destination.$final_name);
				$image_object->ThumbCreate($destination.$final_name, $min_name , $contents_object->P_MAX_PHOTO_MIN_WIDTH);
				
				// on retaille l'original au besoin.
				if(PHOTO_RESIZE===true && ExcedMaxSize($destination.$final_name, $contents_object->P_MAX_PHOTO_MAX_WIDTH)) {
					$image_object->ThumbCreate($destination.$final_name, $destination.$final_name , $contents_object->P_MAX_PHOTO_MAX_WIDTH);
				}
				
				// préparation de l'affichage de la miniature
				$visual_link1=EnlargeImage($visual_link1);
			}
        } elseif(isset($_POST['part_template'])) $table[3]='';
	}

	
	if(is_string($integrity)) {
		$text_format='2FIELD';
	} else {
		$text_format='2HTML';
	}
	$form_title=formatText($_POST['part_title'], $text_format);
	$form_body=formatText($_POST['part_body'], $text_format);
	if($type=='P') {
		$mask_template[$_POST['part_template']]=' selected="selected"';
		if($_POST['part_template']==3) $layer_tpl_1 = "style=\"display:none;\"";
	}
	
	$table=urlencode(serialize($table));
}

if($type=='P') {
	$requete= SQL_getPublicationTitle($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['publi_title']);
	$publi_owner=$result[0]['publi_posted_by'];
	//////////// Check Droits utilisateur ////////////
	if (!HaveRight('publication')) ReloadIndex('admin');
	if (GetSessionElement('id')!=$publi_owner && !IsSuperAdmin()) ReloadIndex('admin');
	///////////
	
	// select-box Templates
	$select_template="<select name=\"part_template\" id=\"part_template\" onchange=\"ShowFilesLayer(this.value, 'contents')\">\n";
	$select_template.="<option value=\"1\"".$mask_template[1].">".$contents_object->GetTemplateName(1)."</option>\n";
	$select_template.="<option value=\"2\"".$mask_template[2].">".$contents_object->GetTemplateName(2)."</option>\n";
	$select_template.="<option value=\"3\"".$mask_template[3].">".$contents_object->GetTemplateName(3)."</option>\n";
	$select_template.="</select>\n";
}

if($type=='W') {
	$requete= SQL_getWorkshopRepTitleAndGroup($parent);
	$result=$sql_object->DBSelect($requete);
	$current_title=FormatText($result[0]['workrep_title']).' ('.FormatText($result[0]['workshop_denomination']).')';
	$workshop_id=$result[0]['workrep_workshop_id'];
	//////////// Check Droits utilisateur ////////////
	if (!HaveRight('workshop')) ReloadIndex('admin');
	if (!AuthUser4Workshop($workshop_id, $sql_object) && !IsSuperAdmin()) ReloadIndex('admin');
	///////////
}




?>

<div id="chemin">
	<ul>
		<li>
			<a href="index.php"><? echo $GLOBALS['lang']['way']['home'] ?></a>
		</li>
		<li>
			<a href="<?php echo $rub_link; ?>"><? echo $GLOBALS['lang']['menu'][$mod_inc]?></a>
		</li>
		<li>
			<span><? echo formatNavTitle($GLOBALS['lang']['contents'][$mod_inc.'_type']." : ". $current_title); ?></span>
		</li>
	</ul>
</div>
<!--end barre haute -->
<?php
include_once("quickicons.php");
?>

<?php
if(!isset($integrity) || is_string($integrity)) {
?>
<div class="contentcontainer">
		<?php
		include_once($dir."/menurub.php");
		?>
		<div id="content">
			<?php
			if(isset($integrity) && is_string($integrity)) display_errors($integrity);
			?>
			<h2><? echo formatTitleh2($GLOBALS['lang']['contents'][$mod_inc.'_type']." : ". $current_title); ?></h2>
			<form id="addpart" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post" enctype="multipart/form-data">
				<p>
				<label for="part_title"><? echo $GLOBALS['lang']['contents']['title']; ?> : *</label>
				<input name="part_title" type="text" class="textfield" id="part_title" maxlength="200" value="<?php echo $form_title; ?>" />
				</p>
				<p>
				<label for="part_body"><? echo $GLOBALS['lang']['contents']['body']; ?> : *</label>
				<textarea id="part_body" name="part_body" class="largetextfield" <?php echo AREA_SETTINGS; ?>><?php echo $form_body; ?></textarea>
				</p>
				<p>
				<?php  if($type=='P') { ?>
				<label for="part_template" ><? echo $GLOBALS['lang']['contents']['template']; ?> : </label>
				<?php echo $select_template; ?>
				</p>
				<p id="layervisuel1" <?php echo $layer_tpl_1; ?>>
					<label for="visuel1"><?php echo $GLOBALS['lang']['contents']['visu1']; ?></label>
					<input name="visuel1" type="file" size="47" id="visuel1"  class="file" /><br /><br />
				</p>
				<?php } ?>
				<div>
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<?php echo cancel_button($cancel_link); ?>
				<input name="valider" type="submit" value="<? echo $GLOBALS['lang']['btn']['valid'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
<?php include_once($dir."/help.php"); ?>
</div>
<?php
// Récapitulatif
} else	{

if($type=='P') {
	if($_POST['part_template']==3) {
		$display_visual=$GLOBALS['lang']['divers']['none'];
	} else {
		$display_visual=$visual_link1;
	}
	$display_template_choice=$contents_object->GetTemplateName($_POST['part_template']);
}

?>
<div class="contentcontainer">
<?php
include_once($dir."/menurub.php");
?>
<div id="content">
			<h2><? echo $GLOBALS['lang']['recap']['title'] ?></h2>
			<?php
			echo "<dl class=\"dl3\">\n";
			echo "<dt>".$GLOBALS['lang']['contents']['title']."</dt>\n";
			echo "<dd>".$form_title."</dd>\n";
			echo "<dt>".$GLOBALS['lang']['contents']['body']."</dt>\n";
			echo "<dd>".linkin_content($form_body)."</dd>\n";
			if($type=='P') {
				echo "<dt>".$GLOBALS['lang']['contents']['template']."</dt>\n";
				echo "<dd>".$display_template_choice."</dd>\n";
				echo "<dt>".$GLOBALS['lang']['contents']['visu1']."</dt>\n";
				echo "<dd>".$display_visual."</dd>\n";
			}
			echo "</dl>\n";
			?>
			<form id="addscale" action="<?php echo $_SERVER['SCRIPT_NAME']; ?>" method="post">
				<div>
				<input name="rub" type="hidden" value="<?php echo $rub; ?>" id="rub" />
				<input name="todo" type="hidden" value="<?php echo $todo; ?>" id="todo" />
				<input name="type" type="hidden" value="<?php echo $type; ?>" id="type" />
				<input name="parent" type="hidden" value="<?php echo $parent; ?>" id="parent" />
				<input name="data_table" type="hidden" value="<?php echo $table; ?>" id="data_table" />
				<input name="retour" type="button" value="<? echo $GLOBALS['lang']['btn']['preview'] ?>" class="button" id="retour" onclick="history.go(-1);" />
				<input name="enregistrer" type="submit" value="<? echo $GLOBALS['lang']['btn']['save'] ?>" class="button" id="valider" />
				</div>
			</form>
		</div>
	<?php include_once($dir."/help.php"); ?>
</div>
<?php
}
?>
